==> benchling_sdk-0.11.0a0-py3-none-any.whl: benchling_api_client/models/folders_archive.py <==
from typing import Any, cast, Dict, List, Type, TypeVar

import attr

from ..models.folders_archive_reason import FoldersArchiveReason

T = TypeVar("T", bound="FoldersArchive")


@attr.s(auto_attribs=True, repr=False)
class FoldersArchive:
    """  """

    _folder_ids: List[str]
    _reason: FoldersArchiveReason

    def __repr__(self):
        fields = []
        fields.append("folder_ids={}".format(repr(self._folder_ids)))
        fields.append("reason={}".format(repr(self._reason)))
        return "FoldersArchive({})".format(", ".join(fields))

    def to_dict(self) -> Dict[str, Any]:
        folder_ids = self._folder_ids

        reason = self._reason.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "folderIds": folder_ids,
                "reason": reason,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        folder_ids = cast(List[str], d.pop("folderIds"))

        reason = FoldersArchiveReason(d.pop("reason"))

        folders_archive = cls(
            folder_ids=folder_ids,
            reason=reason,
        )

        return folders_archive

    @property
    def folder_ids(self) -> List[str]:
        return self._folder_ids

    @folder_ids.setter
    def folder_ids(self, value: List[str]) -> None:
        self._folder_ids = value

    @property
    def reason(self) -> FoldersArchiveReason:
        return self._reason

    @reason.setter
    def reason(self, value: FoldersArchiveReason) -> None:
        self._reason = value

==> benchling_sdk-1.0.3-py3-none-any.whl: benchling_api_client/models/folders_archive.py <==
from typing import Any, cast, Dict, List, Type, TypeVar

import attr

from ..models.folders_archive_reason import FoldersArchiveReason

T = TypeVar("T", bound="FoldersArchive")


@attr.s(auto_attribs=True, repr=False)
class FoldersArchive:
    """  """

    _folder_ids: List[str]
    _reason: FoldersArchiveReason

    def __repr__(self):
        fields = []
        fields.append("folder_ids={}".format(repr(self._folder_ids)))
        fields.append("reason={}".format(repr(self._reason)))
        return "FoldersArchive({})".format(", ".join(fields))

    def to_dict(self) -> Dict[str, Any]:
        folder_ids = self._folder_ids

        reason = self._reason.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "folderIds": folder_ids,
                "reason": reason,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        folder_ids = cast(List[str], d.pop("folderIds"))

        _reason = d.pop("reason")
        try:
            reason = FoldersArchiveReason(_reason)
        except ValueError:
            reason = FoldersArchiveReason.of_unknown(_reason)

        folders_archive = cls(
            folder_ids=folder_ids,
            reason=reason,
        )

        return folders_archive

    @property
    def folder_ids(self) -> List[str]:
        """ A list of folder IDs to archive. """
        return self._folder_ids

    @folder_ids.setter
    def folder_ids(self, value: List[str]) -> None:
        self._folder_ids = value

    @property
    def reason(self) -> FoldersArchiveReason:
        """The reason for archiving the provided folders. Accepted reasons may differ based on tenant configuration."""
        return self._reason

    @reason.setter
    def reason(self, value: FoldersArchiveReason) -> None:
        self._reason = value
